@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef GRANTLEETHEME_GENERICFORMATTER_H
@@ -27,8 +15,8 @@
 
 class QString;
 
-namespace GrantleeTheme {
-
+namespace GrantleeTheme
+{
 class GenericFormatterPrivate;
 
 /** Convenience class for using a Grantlee theme. */
@@ -56,7 +44,6 @@ public:
 private:
     std::unique_ptr<GenericFormatterPrivate> const d;
 };
-
 }
 
 #endif // GRANTLEETHEME_GENERICFORMATTER_H
